###
### read_surmisefunction.R
###

read_surmisefunction <- function (filename) {
  sf <- read.csv(filename)
  class(sf) <- unique(c("kmsurmisefunction", class(sf)))
}